pub struct ListGrantsPaginatorItems(/* private fields */);Expand description
Flattened paginator for ListGrantsPaginator
This is created with .items()
Implementations
Sourceimpl ListGrantsPaginatorItems
impl ListGrantsPaginatorItems
Sourcepub fn send(
self,
) -> PaginationStream<Result<GrantListEntry, SdkError<ListGrantsError, HttpResponse>>>
pub fn send( self, ) -> PaginationStream<Result<GrantListEntry, SdkError<ListGrantsError, HttpResponse>>>
Create the pagination stream
Note: No requests will be dispatched until the stream is used
(e.g. with the .next().await method).
To read the entirety of the paginator, use .collect::<Result<Vec<_>, _>().